@@ -1,6 +1,5 @@
 use anyhow::Result;
 use format_buf::format;
-use num_bigint::BigInt;
 
 use std::any::Any;
 
@@ -14,7 +13,7 @@ impl Value for BuildInfo {
 			OP_FIELD_ACCESS => match as_field_name(args) {
 				"timestamp" => Ok(Box::new(self.timestamp)),
 				"profile" => Ok(Box::new(self.profile.clone())),
-				"optimization_level" => Ok(Box::new(BigInt::from(self.optimization_level))),
+				"optimization_level" => Ok(Box::new(self.optimization_level)),
 				"crate_info" => Ok(Box::new(self.crate_info.clone())),
 				"compiler" => Ok(Box::new(self.compiler.clone())),
 				"version_control" => Ok(Box::new(self.version_control.clone())),
@@ -38,9 +37,9 @@ impl Value for BuildInfo {
 
 	fn format(&self, buffer: &mut String, spec: FormatSpecifier) {
 		match spec {
-			FormatSpecifier::Default => format!(buffer, "{}", self),
-			FormatSpecifier::Debug => format!(buffer, "{:?}", self),
-			FormatSpecifier::DebugAlt => format!(buffer, "{:#?}", self),
+			FormatSpecifier::Default => format!(buffer, "{self}"),
+			FormatSpecifier::Debug => format!(buffer, "{self:?}"),
+			FormatSpecifier::DebugAlt => format!(buffer, "{self:#?}"),
 		}
 	}
 }
